function DI_contributions = compute_DI_contributions(P, f, threshold, diversity_indicator)
%
%
%
% Authors: Johannes W. Kruisselbrink, Michael T.M. Emmerich, Andre H. Deutz

	% Compute the set diversity for the current set
	% based on the given diversity indicator
	total_set_distance = feval(diversity_indicator, P, f, threshold);

	DI_contributions = NaN(1,size(P,2));

	% Compute set diversity according to the diversity indicator
	% every time leaving one solution out of the population
	for i = 1:size(P,2)

		% Construct the set leaving out solution i
		P_prime = P(:,[1:(i-1),(i+1):end]);
		f_prime = f([1:(i-1),(i+1):end]);

		% Compute the diversity for the current set
		current_set_distance = feval(diversity_indicator, P_prime, f_prime, threshold);

		% Compute the diversity contribution of solution i
		DI_contributions(i) = total_set_distance - current_set_distance;

	end

end
