function [] = experiments_ELSA()
% [] = experiments_ELSA()
%
% Runs the ELSA algorithm with different quality indicators on
% the sphere problem and Branke's multipeak problem
%
% Authors: Johannes W. Kruisselbrink, Michael T.M. Emmerich, Andre H. Deutz

	stopeval		= 10000;
	visualization	= false;

	% ------------------------------------------------------------------------
	% Setup the the experiments for the sphere
	% ------------------------------------------------------------------------
	objective_fct 	= @sphere;
	threshold		= sphere([1,0]);
	N				= 2;
	lb				= -2 * ones(N,1);
	ub				= 2 * ones(N,1);
%	run_experiment(objective_fct, threshold, N, lb, ub, stopeval, visualization)
	experiments_file = ['Results/results_ELSA_experiments_', func2str(objective_fct)];
	plot_results_ELSA_experiments(objective_fct, threshold, N, lb, ub, experiments_file)

	% ------------------------------------------------------------------------
	% Setup the the experiments for the sphere
	% ------------------------------------------------------------------------
	objective_fct 	= @branke_multipeak;
	threshold		= 0.6;
	N				= 2;
	lb				= -2 * ones(N,1);
	ub				= 2 * ones(N,1);
%	run_experiment(objective_fct, threshold, N, lb, ub, stopeval, visualization)
	experiments_file = ['Results/results_ELSA_experiments_', func2str(objective_fct)];
	plot_results_ELSA_experiments(objective_fct, threshold, N, lb, ub, experiments_file)

end


function [] = run_experiment(objective_fct, threshold, N, lb, ub, stopeval, visualization)

	% ------------------------------------------------------------------------
	% Setup the diversity indicators
	% ------------------------------------------------------------------------
	DI_ADI		= @(P, f, threshold) D_ADI_augmented(P, f, N, lb, ub, threshold);
	DI_SP_l		= @(P, f, threshold) D_SP_augmented(P, f, N, lb, ub, threshold, 1);
	DI_SP_m		= @(P, f, threshold) D_SP_augmented(P, f, N, lb, ub, threshold, 10);
	DI_SP_h		= @(P, f, threshold) D_SP_augmented(P, f, N, lb, ub, threshold, 1000);
	DI_PI		= @(P, f, threshold) D_PI_augmented(P, f, N, lb, ub, threshold);
	DI_SIGMA	= @(P, f, threshold) D_SIGMA_augmented(P, f, N, lb, ub, threshold);
	DI_gap		= @(P, f, threshold) D_gap_augmented(P, f, N, lb, ub, threshold);

	% ------------------------------------------------------------------------
	% Run the experiments
	% ------------------------------------------------------------------------
	disp('P_ADI')
	[P_ADI]		= ELSA(objective_fct, threshold, N, lb, ub, stopeval, 'diversity_indicator', DI_ADI, 'visualization', visualization);
	disp('P_ADI_xs')
	[P_ADI_xs]	= ELSA(objective_fct, threshold, N, 0.5 * lb, 0.5 * ub, stopeval, 'diversity_indicator', DI_ADI, 'visualization', visualization);
	disp('P_ADI_xl')
	[P_ADI_xl]	= ELSA(objective_fct, threshold, N, 4 * lb, 4 * ub, stopeval, 'diversity_indicator', DI_ADI, 'visualization', visualization);
	disp('P_SP_l')
	[P_SP_l]	= ELSA(objective_fct, threshold, N, lb, ub, stopeval, 'diversity_indicator', DI_SP_l, 'visualization', visualization);
	disp('P_SP_m')
	[P_SP_m]	= ELSA(objective_fct, threshold, N, lb, ub, stopeval, 'diversity_indicator', DI_SP_m, 'visualization', visualization);
	disp('P_SP_h')
	[P_SP_h]	= ELSA(objective_fct, threshold, N, lb, ub, stopeval, 'diversity_indicator', DI_SP_h, 'visualization', visualization);
	disp('P_gap')
	[P_gap]		= ELSA(objective_fct, threshold, N, lb, ub, stopeval, 'diversity_indicator', DI_gap, 'visualization', visualization);
	disp('P_PI')
	[P_PI]		= ELSA(objective_fct, threshold, N, lb, ub, stopeval, 'diversity_indicator', DI_PI, 'visualization', visualization);
	disp('P_SIGMA')
	[P_SIGMA]	= ELSA(objective_fct, threshold, N, lb, ub, stopeval, 'diversity_indicator', DI_SIGMA, 'visualization', visualization);

	% ------------------------------------------------------------------------
	% Save the statistics
	% ------------------------------------------------------------------------
	experiments_file = ['Results/results_ELSA_experiments_', func2str(objective_fct)];
	save(experiments_file, 'P_ADI', 'P_ADI_xs', 'P_ADI_xl', 'P_SP_l', 'P_SP_m', 'P_SP_h', 'P_gap', 'P_PI', 'P_SIGMA');

	% ------------------------------------------------------------------------
	% Plot the statistics
	% ------------------------------------------------------------------------
	plot_results_ELSA_experiments(objective_fct, threshold, N, lb, ub, experiments_file)

end
